// File created from ../../../src/bin/dhcp4/dhcp4_messages.mes on Mon Nov 18 2013 12:20

#include <cstddef>
#include <log/message_types.h>
#include <log/message_initializer.h>

namespace isc {
namespace dhcp {

extern const isc::log::MessageID DHCP4_CCSESSION_STARTED = "DHCP4_CCSESSION_STARTED";
extern const isc::log::MessageID DHCP4_CCSESSION_STARTING = "DHCP4_CCSESSION_STARTING";
extern const isc::log::MessageID DHCP4_COMMAND_RECEIVED = "DHCP4_COMMAND_RECEIVED";
extern const isc::log::MessageID DHCP4_CONFIG_COMPLETE = "DHCP4_CONFIG_COMPLETE";
extern const isc::log::MessageID DHCP4_CONFIG_LOAD_FAIL = "DHCP4_CONFIG_LOAD_FAIL";
extern const isc::log::MessageID DHCP4_CONFIG_NEW_SUBNET = "DHCP4_CONFIG_NEW_SUBNET";
extern const isc::log::MessageID DHCP4_CONFIG_OPTION_DUPLICATE = "DHCP4_CONFIG_OPTION_DUPLICATE";
extern const isc::log::MessageID DHCP4_CONFIG_START = "DHCP4_CONFIG_START";
extern const isc::log::MessageID DHCP4_CONFIG_UPDATE = "DHCP4_CONFIG_UPDATE";
extern const isc::log::MessageID DHCP4_DB_BACKEND_STARTED = "DHCP4_DB_BACKEND_STARTED";
extern const isc::log::MessageID DHCP4_LEASE_ADVERT = "DHCP4_LEASE_ADVERT";
extern const isc::log::MessageID DHCP4_LEASE_ADVERT_FAIL = "DHCP4_LEASE_ADVERT_FAIL";
extern const isc::log::MessageID DHCP4_LEASE_ALLOC = "DHCP4_LEASE_ALLOC";
extern const isc::log::MessageID DHCP4_LEASE_ALLOC_FAIL = "DHCP4_LEASE_ALLOC_FAIL";
extern const isc::log::MessageID DHCP4_NOT_RUNNING = "DHCP4_NOT_RUNNING";
extern const isc::log::MessageID DHCP4_OPEN_SOCKET = "DHCP4_OPEN_SOCKET";
extern const isc::log::MessageID DHCP4_PACKET_PARSE_FAIL = "DHCP4_PACKET_PARSE_FAIL";
extern const isc::log::MessageID DHCP4_PACKET_PROCESS_FAIL = "DHCP4_PACKET_PROCESS_FAIL";
extern const isc::log::MessageID DHCP4_PACKET_RECEIVED = "DHCP4_PACKET_RECEIVED";
extern const isc::log::MessageID DHCP4_PACKET_RECEIVE_FAIL = "DHCP4_PACKET_RECEIVE_FAIL";
extern const isc::log::MessageID DHCP4_PACKET_SEND_FAIL = "DHCP4_PACKET_SEND_FAIL";
extern const isc::log::MessageID DHCP4_PACK_FAIL = "DHCP4_PACK_FAIL";
extern const isc::log::MessageID DHCP4_PARSER_COMMIT_EXCEPTION = "DHCP4_PARSER_COMMIT_EXCEPTION";
extern const isc::log::MessageID DHCP4_PARSER_COMMIT_FAIL = "DHCP4_PARSER_COMMIT_FAIL";
extern const isc::log::MessageID DHCP4_PARSER_CREATED = "DHCP4_PARSER_CREATED";
extern const isc::log::MessageID DHCP4_PARSER_EXCEPTION = "DHCP4_PARSER_EXCEPTION";
extern const isc::log::MessageID DHCP4_PARSER_FAIL = "DHCP4_PARSER_FAIL";
extern const isc::log::MessageID DHCP4_QUERY_DATA = "DHCP4_QUERY_DATA";
extern const isc::log::MessageID DHCP4_RELEASE = "DHCP4_RELEASE";
extern const isc::log::MessageID DHCP4_RELEASE_EXCEPTION = "DHCP4_RELEASE_EXCEPTION";
extern const isc::log::MessageID DHCP4_RELEASE_FAIL = "DHCP4_RELEASE_FAIL";
extern const isc::log::MessageID DHCP4_RELEASE_FAIL_NO_LEASE = "DHCP4_RELEASE_FAIL_NO_LEASE";
extern const isc::log::MessageID DHCP4_RELEASE_FAIL_WRONG_CLIENT_ID = "DHCP4_RELEASE_FAIL_WRONG_CLIENT_ID";
extern const isc::log::MessageID DHCP4_RELEASE_FAIL_WRONG_HWADDR = "DHCP4_RELEASE_FAIL_WRONG_HWADDR";
extern const isc::log::MessageID DHCP4_RESPONSE_DATA = "DHCP4_RESPONSE_DATA";
extern const isc::log::MessageID DHCP4_SERVERID_GENERATED = "DHCP4_SERVERID_GENERATED";
extern const isc::log::MessageID DHCP4_SERVERID_LOADED = "DHCP4_SERVERID_LOADED";
extern const isc::log::MessageID DHCP4_SERVERID_WRITE_FAIL = "DHCP4_SERVERID_WRITE_FAIL";
extern const isc::log::MessageID DHCP4_SERVER_FAILED = "DHCP4_SERVER_FAILED";
extern const isc::log::MessageID DHCP4_SESSION_FAIL = "DHCP4_SESSION_FAIL";
extern const isc::log::MessageID DHCP4_SHUTDOWN = "DHCP4_SHUTDOWN";
extern const isc::log::MessageID DHCP4_SHUTDOWN_REQUEST = "DHCP4_SHUTDOWN_REQUEST";
extern const isc::log::MessageID DHCP4_SRV_CONSTRUCT_ERROR = "DHCP4_SRV_CONSTRUCT_ERROR";
extern const isc::log::MessageID DHCP4_STANDALONE = "DHCP4_STANDALONE";
extern const isc::log::MessageID DHCP4_STARTING = "DHCP4_STARTING";
extern const isc::log::MessageID DHCP4_START_INFO = "DHCP4_START_INFO";
extern const isc::log::MessageID DHCP4_SUBNET_SELECTED = "DHCP4_SUBNET_SELECTED";
extern const isc::log::MessageID DHCP4_SUBNET_SELECTION_FAILED = "DHCP4_SUBNET_SELECTION_FAILED";

} // namespace dhcp
} // namespace isc

namespace {

const char* values[] = {
    "DHCP4_CCSESSION_STARTED", "control channel session started on socket %1",
    "DHCP4_CCSESSION_STARTING", "starting control channel session, specfile: %1",
    "DHCP4_COMMAND_RECEIVED", "received command %1, arguments: %2",
    "DHCP4_CONFIG_COMPLETE", "DHCPv4 server has completed configuration: %1",
    "DHCP4_CONFIG_LOAD_FAIL", "failed to load configuration: %1",
    "DHCP4_CONFIG_NEW_SUBNET", "A new subnet has been added to configuration: %1",
    "DHCP4_CONFIG_OPTION_DUPLICATE", "multiple options with the code %1 added to the subnet %2",
    "DHCP4_CONFIG_START", "DHCPv4 server is processing the following configuration: %1",
    "DHCP4_CONFIG_UPDATE", "updated configuration received: %1",
    "DHCP4_DB_BACKEND_STARTED", "lease database started (type: %1, name: %2)",
    "DHCP4_LEASE_ADVERT", "lease %1 advertised (client client-id %2, hwaddr %3)",
    "DHCP4_LEASE_ADVERT_FAIL", "failed to advertise a lease for client client-id %1, hwaddr %2",
    "DHCP4_LEASE_ALLOC", "lease %1 has been allocated for client-id %2, hwaddr %3",
    "DHCP4_LEASE_ALLOC_FAIL", "failed to grant a lease for client-id %1, hwaddr %2",
    "DHCP4_NOT_RUNNING", "IPv4 DHCP server is not running",
    "DHCP4_OPEN_SOCKET", "opening sockets on port %1",
    "DHCP4_PACKET_PARSE_FAIL", "failed to parse incoming packet: %1",
    "DHCP4_PACKET_PROCESS_FAIL", "failed to process packet received from %1: %2",
    "DHCP4_PACKET_RECEIVED", "%1 (type %2) packet received on interface %3",
    "DHCP4_PACKET_RECEIVE_FAIL", "error on attempt to receive packet: %1",
    "DHCP4_PACKET_SEND_FAIL", "failed to send DHCPv4 packet: %1",
    "DHCP4_PACK_FAIL", "failed to assemble response correctly",
    "DHCP4_PARSER_COMMIT_EXCEPTION", "parser failed to commit changes",
    "DHCP4_PARSER_COMMIT_FAIL", "parser failed to commit changes: %1",
    "DHCP4_PARSER_CREATED", "created parser for configuration element %1",
    "DHCP4_PARSER_EXCEPTION", "failed to create or run parser for configuration element %1",
    "DHCP4_PARSER_FAIL", "failed to create or run parser for configuration element %1: %2",
    "DHCP4_QUERY_DATA", "received packet type %1, data is <%2>",
    "DHCP4_RELEASE", "address %1 belonging to client-id %2, hwaddr %3 was released properly.",
    "DHCP4_RELEASE_EXCEPTION", "exception %1 while trying to release address %2",
    "DHCP4_RELEASE_FAIL", "failed to remove lease for address %1 for duid %2, hwaddr %3",
    "DHCP4_RELEASE_FAIL_NO_LEASE", "client (client-id %2) tried to release address %1, but there is no lease for such address.",
    "DHCP4_RELEASE_FAIL_WRONG_CLIENT_ID", "client (client-id %2) tried to release address %1, but it belongs to client (client-id %3)",
    "DHCP4_RELEASE_FAIL_WRONG_HWADDR", "client (client-id %2) tried to release address %1, but sent from a wrong hardware address (%3)",
    "DHCP4_RESPONSE_DATA", "responding with packet type %1, data is <%2>",
    "DHCP4_SERVERID_GENERATED", "server-id %1 has been generated and will be stored in %2",
    "DHCP4_SERVERID_LOADED", "server-id %1 has been loaded from file %2",
    "DHCP4_SERVERID_WRITE_FAIL", "server was not able to write its ID to file %1",
    "DHCP4_SERVER_FAILED", "server failed: %1",
    "DHCP4_SESSION_FAIL", "failed to establish BIND 10 session (%1), running stand-alone",
    "DHCP4_SHUTDOWN", "server shutdown",
    "DHCP4_SHUTDOWN_REQUEST", "shutdown of server requested",
    "DHCP4_SRV_CONSTRUCT_ERROR", "error creating Dhcpv4Srv object, reason: %1",
    "DHCP4_STANDALONE", "skipping message queue, running standalone",
    "DHCP4_STARTING", "server starting",
    "DHCP4_START_INFO", "pid: %1, port: %2, verbose: %3, standalone: %4",
    "DHCP4_SUBNET_SELECTED", "the %1 subnet was selected for client assignment",
    "DHCP4_SUBNET_SELECTION_FAILED", "failed to select a subnet for incoming packet, src: %1, type: %2",
    NULL
};

const isc::log::MessageInitializer initializer(values);

} // Anonymous namespace

